#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.cat_sch_platform_interfaces.sch_list_of_bst_rs import SchListOfBSTRs
from pycatia.system_interfaces.any_object import AnyObject


class SchAppCntrData(AnyObject):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     SchAppCntrData
                | 
                | Manage a schematic connector data.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.sch_app_cntr_data = com_object

    def app_get_application_data(self, i_l_app_data: SchListOfBSTRs, i_l_app_nls_data: SchListOfBSTRs) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub AppGetApplicationData(SchListOfBSTRs iLAppData,
                | SchListOfBSTRs iLAppNlsData)
                | 
                |     Get application data.
                | 
                |     Parameters:
                | 
                |         iLAppData
                |             A list of character string data. 
                |         iLAppNlsData
                |             A list of character string data. 
                | 
                |     Example:
                | 
                |           
                | 
                |          Dim objThisIntf As SchAppCntrData
                |          Dim objArg1 As SchListOfBSTRs
                |          Dim objArg2 As SchListOfBSTRs
                |           ...
                |          objThisIntf.AppGetApplicationDataobjArg1,objArg2

        :param SchListOfBSTRs i_l_app_data:
        :param SchListOfBSTRs i_l_app_nls_data:
        :rtype: None
        """
        return self.sch_app_cntr_data.AppGetApplicationData(i_l_app_data.com_object, i_l_app_nls_data.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'app_get_application_data'
        # # vba_code = """
        # # Public Function app_get_application_data(sch_app_cntr_data)
        # #     Dim iLAppData (2)
        # #     sch_app_cntr_data.AppGetApplicationData iLAppData
        # #     app_get_application_data = iLAppData
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def app_list_potential_data(self, i_l_app_data: SchListOfBSTRs, i_l_app_nls_data: SchListOfBSTRs) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub AppListPotentialData(SchListOfBSTRs iLAppData,
                | SchListOfBSTRs iLAppNlsData)
                | 
                |     Get a list valid potential application data that can be
                |     set.
                | 
                |     Parameters:
                | 
                |         iLAppData
                |             A list of character string data. 
                |         iLAppNlsData
                |             A list of character string data. 
                | 
                |     Example:
                | 
                |           
                | 
                |          Dim objThisIntf As SchAppCntrData
                |          Dim objArg1 As SchListOfBSTRs
                |          Dim objArg2 As SchListOfBSTRs
                |           ...
                |          objThisIntf.AppListPotentialDataobjArg1,objArg2

        :param SchListOfBSTRs i_l_app_data:
        :param SchListOfBSTRs i_l_app_nls_data:
        :rtype: None
        """
        return self.sch_app_cntr_data.AppListPotentialData(i_l_app_data.com_object, i_l_app_nls_data.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'app_list_potential_data'
        # # vba_code = """
        # # Public Function app_list_potential_data(sch_app_cntr_data)
        # #     Dim iLAppData (2)
        # #     sch_app_cntr_data.AppListPotentialData iLAppData
        # #     app_list_potential_data = iLAppData
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def app_set_application_data(self, i_l_app_data: SchListOfBSTRs) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub AppSetApplicationData(SchListOfBSTRs iLAppData)
                | 
                |     Set application data.
                | 
                |     Parameters:
                | 
                |         iLAppData
                |             A list of character string data. 
                | 
                |     Example:
                | 
                |           
                | 
                |          Dim objThisIntf As SchAppCntrData
                |          Dim objArg1 As SchListOfBSTRs
                |           ...
                |          objThisIntf.AppSetApplicationDataobjArg1

        :param SchListOfBSTRs i_l_app_data:
        :rtype: None
        """
        return self.sch_app_cntr_data.AppSetApplicationData(i_l_app_data.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'app_set_application_data'
        # # vba_code = """
        # # Public Function app_set_application_data(sch_app_cntr_data)
        # #     Dim iLAppData (2)
        # #     sch_app_cntr_data.AppSetApplicationData iLAppData
        # #     app_set_application_data = iLAppData
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def __repr__(self):
        return f'SchAppCntrData(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.abq_automation_interfaces.abq_load import ABQLoad


class ABQIAABQFrequencyLoadingVB(ABQLoad):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     ABQAutomationItf.ABQLoad
                |                         ABQIAABQFrequencyLoadingVB
                | 
                | Interface representing xxx.
                | 
                | Role: Components that implement ABQIAABQFrequencyLoading are
                | ...
                | 
                | Do not use the ABQIAABQFrequencyLoading interface for such and such
                | ClassReference, Class#MethodReference, #InternalMethod...
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.abqiaabq_frequency_loading_vb = com_object

    @property
    def dof(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property DOF() As double

        :rtype: float
        """

        return self.abqiaabq_frequency_loading_vb.DOF

    @dof.setter
    def dof(self, value: float):
        """
        :param float value:
        """

        self.abqiaabq_frequency_loading_vb.DOF = value

    @property
    def data_type(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property DataType() As boolean

        :rtype: bool
        """

        return self.abqiaabq_frequency_loading_vb.DataType

    @data_type.setter
    def data_type(self, value: bool):
        """
        :param bool value:
        """

        self.abqiaabq_frequency_loading_vb.DataType = value

    @property
    def frequency_data_values(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property FrequencyDataValues(CATSafeArrayVariant iFreqDataVal) (Write
                | Only)

        :rtype: int
        """

        return self.abqiaabq_frequency_loading_vb.FrequencyDataValues

    @frequency_data_values.setter
    def frequency_data_values(self, value: int):
        """
        :param int value:
        """

        self.abqiaabq_frequency_loading_vb.FrequencyDataValues = value

    @property
    def imaginary_data_values(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property ImaginaryDataValues(CATSafeArrayVariant iImaginaryDataValues)
                | (Write Only)

        :rtype: int
        """

        return self.abqiaabq_frequency_loading_vb.ImaginaryDataValues

    @imaginary_data_values.setter
    def imaginary_data_values(self, value: int):
        """
        :param int value:
        """

        self.abqiaabq_frequency_loading_vb.ImaginaryDataValues = value

    @property
    def real_data_values(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property RealDataValues(CATSafeArrayVariant iRealDataVal) (Write
                | Only)

        :rtype: int
        """

        return self.abqiaabq_frequency_loading_vb.RealDataValues

    @real_data_values.setter
    def real_data_values(self, value: int):
        """
        :param int value:
        """

        self.abqiaabq_frequency_loading_vb.RealDataValues = value

    @property
    def scale(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property Scale() As double

        :rtype: float
        """

        return self.abqiaabq_frequency_loading_vb.Scale

    @scale.setter
    def scale(self, value: float):
        """
        :param float value:
        """

        self.abqiaabq_frequency_loading_vb.Scale = value

    def __repr__(self):
        return f'ABQIAABQFrequencyLoadingVB(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.cat_plant_ship_interfaces.psp_list_of_bstrs import PSPListOfBSTRs
from pycatia.cat_plant_ship_interfaces.psp_list_of_doubles import PSPListOfDoubles
from pycatia.cat_plant_ship_interfaces.psp_list_of_longs import PSPListOfLongs
from pycatia.cat_plant_ship_interfaces.psp_list_of_objects import PSPListOfObjects
from pycatia.system_interfaces.any_object import AnyObject


class PSPTempListFactory(AnyObject):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     PspTempListFactory
                | 
                | Create temporary (non-persistent) lists to be used in VB
                | environment.
                | Role: Create lists in VB environment.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.psp_temp_list_factory = com_object

    def create_list_of_bst_rs(self) -> PSPListOfBSTRs:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func CreateListOfBSTRs() As PspListOfBSTRs
                | 
                |     Returns a new empty list of strings.
                | 
                |     Returns:
                |         a empty list of strings.
                |
                |     Example:
                | 
                |           This example illustrates how to create a new empty list of
                |           strings.
                |
                |          Dim PspListFact As PspTempListFactory
                |          Dim NewList As PspListOfBSTRs
                |          Set NewList = PspListFact.CreateListOfBSTRs

        :rtype: PSPListOfBSTRs
        """
        return PSPListOfBSTRs(self.psp_temp_list_factory.CreateListOfBSTRs())

    def create_list_of_doubles(self) -> PSPListOfDoubles:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func CreateListOfDoubles() As PspListOfDoubles
                | 
                |     Returns a new empty list of doubles.
                | 
                |     Returns:
                |         a empty list of doubles.
                |
                |     Example:
                | 
                |           This example illustrates how to create a new empty list of
                |           doubles.
                |
                |          Dim PspListFact As PspTempListFactory
                |          Dim NewList As PspListOfDoubles
                |          Set NewList = PspListFact.CreateListOfDoubles

        :rtype: PSPListOfDoubles
        """
        return PSPListOfDoubles(self.psp_temp_list_factory.CreateListOfDoubles())

    def create_list_of_longs(self) -> PSPListOfLongs:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func CreateListOfLongs() As PspListOfLongs
                | 
                |     Returns a new empty list of long integers.
                | 
                |     Returns:
                |         a empty list of long integers.
                |
                |     Example:
                | 
                |           This example illustrates how to create a new empty list of long
                |           integers.
                |
                |          Dim PspListFact As PspTempListFactory
                |          Dim NewList As PspListOfLongs
                |          Set NewList = PspListFact.CreateListOfLongs

        :rtype: PSPListOfLongs
        """
        return PSPListOfLongs(self.psp_temp_list_factory.CreateListOfLongs())

    def create_list_of_objects(self) -> PSPListOfObjects:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func CreateListOfObjects() As PspListOfObjects
                | 
                |     Returns a new empty list of objects.
                | 
                |     Returns:
                |         a empty list of objects.
                |
                |     Example:
                | 
                |           This example illustrates how to create a new empty list of
                |           objects.
                |
                |          Dim PspListFact As PspTempListFactory
                |          Dim NewList As PspListOfObjects
                |          Set NewList = PspListFact.CreateListOfObjects

        :rtype: PSPListOfObjects
        """
        return PSPListOfObjects(self.psp_temp_list_factory.CreateListOfObjects())

    def __repr__(self):
        return f'PSPTempListFactory(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.drafting_2dL_interfaces.layout_2d_view import Layout2DView
from pycatia.system_interfaces.collection import Collection
from pycatia.types.general import cat_variant


class Layout2DViews(Collection):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.Collection
                |                     Layout2DViews

    
    """

    def __init__(self, com_object):
        super().__init__(com_object, child_object=Layout2DView)
        self.layout2_d_views = com_object

    @property
    def active_view(self) -> Layout2DView:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property ActiveView() As Layout2DView (Read Only)
                | 
                |     Returns the active Layout2D view of the active Layout2D
                |     sheet.
                | 
                |     Example:
                |         The following example retrieves in ViewToWorkIn the active Layout2D
                |         view in the Layout2DSheets collection of the
                |         layoutRoot
                | 
                |          Dim MyRoot As Layout2DRoot
                |          Set MyRoot = CATIA.Documents.Part.GetItem("CATLayoutRoot")
                |          Dim ViewToWorkIn As Layout2DView
                |          Set ViewToWorkIn = MyRoot.Sheets.ActiveSheet.Layout2DViews.ActiveView

        :rtype: Layout2DView
        """

        return Layout2DView(self.layout2_d_views.ActiveView)

    def add_auxiliary(self, i_reference_view: Layout2DView, i_bc_segment: tuple, i_xorient: float, i_yorient: float,
                      i_section_type: int, i_x: float, i_y: float) -> Layout2DView:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func AddAuxiliary(Layout2DView iReferenceView,
                | CATSafeArrayVariant iBCSegment,
                | double iXorient,
                | double iYorient,
                | CatViewType iSectionType,
                | double iX,
                | double iY) As Layout2DView
                | 
                |     Creates a section or section-cut or auxiliary View2DL from a given Layout
                |     View2DL. The View2DL must be in this collection. Caracteristics of new view
                |     (view plane etc) are computed based on the given basic callout and reference
                |     view 2DL viewplane.
                |     Precondition : 1/ The reference View2DL must be in this collection
                |     Precondition : 2/ The reference View2DL must be a projection view.
                |     Precondition : 3/ The callout segment's length must not be 0.
                |     Precondition : 4/ iViewType must be either auxiliary or section or section cut.
                | 
                |     Parameters:
                | 
                |         iReferenceView
                |             [in] The reference view. Must be a projection View.
                |             
                |         iBCSegment
                |             [in] The callout's segment gives the trace of the auxiliary
                |             View2DL's projection plane in the reference View2DL. It has the following
                |             contents:
                | 
                |             iBCSegment[0] = X1
                |                 x coordinate of the first point 
                |             iBCSegment[1] = Y1
                |                 y coordinate of the first point 
                |             iBCSegment[2] = X2
                |                 x coordinate of the second point 
                |             iBCSegment[3] = Y2
                |                 y coordinate of the second point 
                | 
                |         iBCOrient
                |             [in] The callout's orientation gives the direction taken into
                |             account when Layout2D the auxilliary View2DL. 
                |         iXorient
                |             [in] 
                |         iYorient
                |             [in] This point determine the type taken into account when Layout2D
                |             the auxilliary View2DL. 
                |         iSectionType
                |         iX
                |             [in] 
                |         iY
                |             [in] The coordinate in the Sheet2DL for the new View2DL.
                |             
                | 
                |     Returns:
                |         The created Layout2D view 
                | 
                | Example:
                |     The following example creates a Layout2D view named from the active view
                |     and retrieved in MyView in the Layout2D view collection of the MySheet Layout2D
                |     sheet. This sheet belongs to the Layout2D sheet collection of the
                |     layoutRoot
                | 
                |      Dim x As double
                |      Set x = 10.
                |      Dim y As double
                |      Set y = 10.
                |      Dim MySegment 
                |      ReDim MySegment(3)
                |          MySegment(0) = 10.
                |          MySegment(1) = 200.
                |          MySegment(2) = 100.
                |          MySegment(3) = 200.
                |      Dim MyRoot As Layout2DRoot
                |      Set MyRoot = CATIA.Documents.Part.GetItem("CATLayoutRoot")
                | 
                |      Dim MyFirstView As Layout2DView
                |      Set MyFirstView = MyRoot.Sheets.ActiveSheet.Views.ActiveView
                |      Dim MyView As Layout2DView
                |      Set MyView = MyRoot.Sheets.ActiveSheet.Views.

        :param Layout2DView i_reference_view:
        :param tuple i_bc_segment:
        :param float i_xorient:
        :param float i_yorient:
        :param int i_section_type: enum cat_view_type
        :param float i_x:
        :param float i_y:
        :rtype: Layout2DView
        """
        return Layout2DView(
            self.layout2_d_views.AddAuxiliary(i_reference_view.com_object, i_bc_segment, i_xorient, i_yorient,
                                              i_section_type, i_x, i_y))

    def add_detail(self, i_detail_name: str) -> Layout2DView:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func AddDetail(CATBSTR iDetailName) As Layout2DView
                | 
                |     Creates a detail view and adds it to the layout view collection. This
                |     layout view becomes the active one.
                |     Precondition : The collection view must be a Detail Sheet
                | 
                |     Parameters:
                | 
                |         iDetailName
                |             The name to assign to the created layout view 
                | 
                |     Returns:
                |         The created layout view 
                |     Example:
                | 
                |           The following example creates a detail view named
                |           Ditto
                |          and retrieved in MyView in the layout view collection
                |          
                |          of the MyDetailSheet layout sheet. Where
                |          MyDetailSheet
                |          is the active sheet of the layout sheet collection of the layout
                |          root
                |          
                | 
                |          Dim MyLayoutRoot As Layout2DRoot
                |          Set MyLayoutRoot = CATIA.Documents.Part.GetItem("CATLayoutRoot")
                |          Dim MyDetailSheet As Layout2DSheet
                |          Set MyDetailSheet = .Sheets.ActiveSheet
                |          Dim MyView As Layout2DView
                |          Set MyView = MyDetailSheet.Views.AddDetail("Ditto")
                |          
                | 
                | 
                |          
                | 
                |     Dim MyView As Layout2DView Set MyView = CATIA.ActiveDocument.Part.GetItem("CATLayoutRoot").Sheets.ActiveSheet. Views.AddDetail()

        :param str i_detail_name:
        :rtype: Layout2DView
        """
        return Layout2DView(self.layout2_d_views.AddDetail(i_detail_name))

    def add_from_3d_plane(self, i_plane: tuple, i_view_type: int, i_x: float, i_y: float) -> Layout2DView:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func AddFrom3DPlane(CATSafeArrayVariant iPlane,
                | CatViewType iViewType,
                | double iX,
                | double iY) As Layout2DView
                | 
                |     Creates a viewFrom3D View2DL with the given 3Dplane as its view plane at
                |     the given position in the given Sheet2DL.
                | 
                |     Parameters:
                | 
                |         iPlane
                |             [in] Define the plane on wich the view as to be created It has the
                |             following contents:
                | 
                |             iPlane[0] = X
                |                 x coordinate of plane origin in 3D space 
                |             iPlane[1] = Y
                |                 y coordinate of plane origin in 3D space 
                |             iPlane[2] = Z
                |                 z coordinate of plane origin in 3D space 
                |             iPlane[3] = H1
                |                 Define the direction which the view's viewplane H
                |                 
                |             iPlane[4] = H2
                |                 axis has to be colinear with 
                |             iPlane[5] = H3
                |             iPlane[6] = V1
                |                 Define the direction which the view's viewplane V
                |                 
                |             iPlane[7] = V2
                |                 axis has to be colinear with 
                |             iPlane[8] = V3
                | 
                | 
                |             Precondition : 1/iViewType must be either auxiliary or section or section cut.
                |             Precondition : 2/ iFirstDirection and iSecondDirection must be orthogonal. 
                |         iViewType
                |             The view type: catAuxiliary or catSectionCut or catSectionView
                |             
                |         iX
                |             [in] 
                |         iY
                |             [in] The coordinate of the new View2DL in the Sheet2DL
                |             
                | 
                |     Returns:
                |         The created Layout2D view

        :param tuple i_plane:
        :param int i_view_type: enum cat_view_type
        :param float i_x:
        :param float i_y:
        :rtype: Layout2DView
        """
        return Layout2DView(self.layout2_d_views.AddFrom3DPlane(i_plane, i_view_type, i_x, i_y))

    def add_primary(self, i_x: float, i_y: float) -> Layout2DView:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func AddPrimary(double iX,
                | double iY) As Layout2DView
                | 
                |     Creates a Layout view and adds it to the Layout view collection. This
                |     Layout view becomes the active one.
                | 
                |     Parameters:
                | 
                |         iX
                |             [in] 
                |         iY
                |             [in] The coordinate in the Sheet2DL for the new View2DL.
                |             
                | 
                |     Returns:
                |         The created Layout2D view 
                | 
                | Example:
                |     The following example creates a Layout2D view and retrieved in MyView in
                |     the Layout2D view collection of the Layout2D sheet. This sheet belongs to the
                |     Layout2D sheet collection.
                | 
                |      Dim x as double
                |      Set x = 10.
                |      Dim y as double
                |      Set y = 10.
                |      Dim MyView As Layout2DView
                |      Set MyView = CATIA.ActiveDocument.Part.GetItem("CATLayoutRoot").Sheets.ActiveSheet.
                |                   Views.AddPrimary(x, y).

        :param float i_x:
        :param float i_y:
        :rtype: Layout2DView
        """
        return Layout2DView(self.layout2_d_views.AddPrimary(i_x, i_y))

    def add_related(self, i_reference_view: Layout2DView, i_side: int, i_x: float, i_y: float) -> Layout2DView:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func AddRelated(Layout2DView iReferenceView,
                | CatViewSide iSide,
                | double iX,
                | double iY) As Layout2DView
                | 
                |     Creates a projection or isometric Layout View2DL from a given View2DL. The
                |     view will be created in the same collection as the given View2DL, at the given
                |     position. The caracteristics (ex: view plane etc) of this new View2DL are
                |     computed based on the caracteristics stored in the ViewBox its iReferenceView
                |     is associated with.
                | 
                |     Parameters:
                | 
                |         iReferenceView
                |             [in] The reference View2DL from which the new View2DL is created.
                |             
                |         iSide
                |             [in] Used with the ViewBox and iReferenceView to give the related
                |             view to create (type etc). 
                |         iX
                |             [in] 
                |         iY
                |             [in] The coordinate in the Sheet2DL for the new View2DL.
                |             
                | 
                |     Returns:
                |         The created Layout2D view
                |         Precondition : The reference View2DL must be in this collection 
                | 
                | Example:
                |     The following example creates a Layout2D view named from the active view
                |     and retrieved in MyView in the Layout2D view collection of the MySheet Layout2D
                |     sheet. This sheet belongs to the Layout2D sheet collection of the
                |     layoutRoot.
                | 
                |      Dim x as double
                |      Set x = 10.
                |      Dim y as double
                |      Set y = 10.
                |      Dim MyFirstView As Layout2DView
                |      Set MyFirstView = CATIA.ActiveDocument.Part.GetItem("CATLayoutRoot").Sheets.ActiveSheet.Views.ActiveView
                |      Dim MyView As Layout2DView
                |      Set MyView = CATIA.ActiveDocument.Part.GetItem("CATLayoutRoot").Sheets.ActiveSheet.Views.
                |                   AddRelated(MyFirstView,catLeftSide, x, y)

        :param Layout2DView i_reference_view:
        :param int i_side: enum cat_view_side
        :param float i_x:
        :param float i_y:
        :rtype: Layout2DView
        """
        return Layout2DView(self.layout2_d_views.AddRelated(i_reference_view.com_object, i_side, i_x, i_y))

    def item(self, i_index: cat_variant) -> Layout2DView:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func Item(CATVariant iIndex) As Layout2DView
                | 
                |     Returns a Layout2D view using its index or its name from the Layout2DViews
                |     collection.
                | 
                |     Parameters:
                | 
                |         iIndex
                |             The index or the name of the Layout2D view to retrieve from the
                |             collection of Layout2D views. As a numerics, this index is the rank of the
                |             Layout2D view in the collection. The index of the first Layout2D view in the
                |             collection is 1, and the index of the last Layout2D view is Count. As a string,
                |             it is the name you assigned to the Layout2D view using the
                |             
                | 
                |         AnyObject.Name property or when creating it using the Add method.
                |         
                |     Returns:
                |         The retrieved Layout2D view 
                |     Example:
                | 
                |           This example retrieves in ThisLayout2DView the second Layout2D
                |           view,
                |          and in ThatLayout2DView the Layout2D view named
                |          MyView in the Layout2D view collection of the active sheet of a
                |          layoutRoot
                |          of a part of the active document, supposed to be a part
                |          document.
                |          
                | 
                |          Dim MySheet As Layout2DSheet
                |          Set MySheet = CATIA.ActiveDocument.Part.GetItem("CATLayoutRoot").Sheets.ActiveSheet
                |          Dim ThisLayout2DView As Layout2DView
                |          Set ThisLayout2DView = MySheet.Views.ActiveView.Item(2)
                |          Dim ThatLayout2DView As Layout2DView
                |          Set ThatLayout2DView = MySheet.Views.ActiveView.Item("MyView")

        :param cat_variant i_index:
        :rtype: Layout2DView
        """
        return Layout2DView(self.layout2_d_views.Item(i_index))

    def remove(self, i_index: cat_variant) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub Remove(CATVariant iIndex)
                | 
                |     Removes a layout2D view from the Layout2DViews collection.
                | 
                |     Parameters:
                | 
                |         iIndex
                |             The index or the name of the Layout2D view to remove from the
                |             collection of Layout2D views. As a numerics, this index is the rank of the
                |             Layout2D view in the collection. The index of the first Layout2D view in the
                |             collection is 1, and the index of the last Layout2D view is Count. As a string,
                |             it is the name you assigned to the Layout2D view using the
                |             
                | 
                |         AnyObject.Name property or when creating it using the Add method.
                |         
                | 
                | Example:
                |     The following example removes the third Layout2D view and the Layout2D view
                |     named TopView in the Layout2D view collection of the active sheet of a
                |     layoutRoot of a part of the active document, supposed to be a part
                |     document.
                | 
                |      Dim MySheet As Layout2DSheet
                |      Set MySheet = CATIA.ActiveDocument.Part.GetItem("CATLayoutRoot").Sheets.ActiveSheet
                |      MySheet.ActiveViews.Remove(3)
                |      MySheet.ActiveViews.Remove("TopView")

        :param cat_variant i_index:
        :rtype: None
        """
        return self.layout2_d_views.Remove(i_index)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'remove'
        # # vba_code = """
        # # Public Function remove(layout2_d_views)
        # #     Dim iIndex (2)
        # #     layout2_d_views.Remove iIndex
        # #     remove = iIndex
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def __repr__(self):
        return f'Layout2DViews(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.system_interfaces.any_object import AnyObject


class CD5Template(AnyObject):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     CD5Template
                | 
                | Represents a Template.
                | 
                | Various properties on the object helps to perform operations on the
                | template.
                | 
                | Example:
                | 
                |       The following example indicates how to retrieve the
                |       template.
                |
                |      Dim oTemplate As ENOIACD5Template
                |      Set oTemplate = oTemplates.Item(1)
                |
                | See also:
                |     CD5Templates
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.cd5_template = com_object

    @property
    def template_name(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property TemplateName() As CATBSTR (Read Only)
                | 
                |     Returns (gets) the name of the Template.
                | 
                |     Example:
                | 
                |           The following example gets the name of the Template.
                |
                |          Dim oName As CATBSTR
                |          oName = oTemplate.TemplateName

        :rtype: str
        """

        return self.cd5_template.TemplateName

    @property
    def template_type(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property TemplateType() As CATBSTR (Read Only)
                | 
                |     Returns (gets) the type of the Template.
                | 
                |     Example:
                | 
                |           The following example gets the type of the Template.
                |
                |          Dim oType As CATBSTR
                |          oType = oTemplate.TemplateType

        :rtype: str
        """

        return self.cd5_template.TemplateType

    def download_file(self, i_target_folder: str) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func DownloadFile(CATBSTR iTargetFolder) As CATBSTR
                | 
                |     Downloads the template file to local disk.
                | 
                |     Parameters:
                | 
                |         iiTargetFolder
                |             The Folder Path on local disk where the template file will be
                |             downloaded. 
                | 
                |     Returns:
                |         Full path of the downloaded file. 
                |     Throws:
                | 
                |         -1782306828 : Template object is assigned more than one file.
                |         -1774688310 : Template object is not assigned any file.
                |         -1866082326 : File of same name as that of file assigned to Template object
                |                       is present on download directory.
                | 
                |     Example:
                | 
                |           The following example downloads the template file to local disk
                |           oTemplate:
                |
                |             iTargetFolder : "E:/New folder".
                |
                |          Dim DownloadedFilePath As CATBSTR
                |          DownloadedFilePath = oTemplate.DownloadFile("E:/New folder")

        :param str i_target_folder:
        :rtype: str
        """
        return self.cd5_template.DownloadFile(i_target_folder)

    def __repr__(self):
        return f'CD5Template(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.system_interfaces.setting_controller import SettingController


class ImportD5SettingAtt(SettingController):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     System.SettingController
                |                         ImportD5SettingAtt
                | 
                | Interface to handle parameters of General-Compatibility-DELMIA D5 Tools Options
                | Tab page.
                | Role: This interface is implemented by a component which represents the
                | controller of DELMIA D5 Tools Options parameter settings.
                | 
                |     Methods to set value of each parameter xxx
                |     Methods to get value of each parameter xxx
                |     Methods to get information on each parameter xxx
                |     Methods to lock/unlock value of each parameter xxx
                | 
                | Here are the list of parameters to use and their meanings:
                | 
                |     ImportLibrary: define the D5 root libraries. For several libraries, they
                |     are separated by the character ;.
                |         D:/Syslib;D:/Robotlib; for Windows
                |         /usr/deneb/Syslib;/usr/deneb/Robotlib; for UNIX 
                |     ImportConfigFile: defines the configuration file to
                |     append.
                |     ImportConfigFile: defines the configuration file to
                |     append.
                |     ImportPDBCache : defines the D5 pdb cache directory for UG files.
                |     ImportRecording : defines the option for importing D5 recording file into V5 replays.
                |     ImportUserViews : defines the option for importing D5 user views into V5 cameras.
                |         For workcells only.
                |     ImportAnnotation: defines the option for importing D5 annotations into V5
                |     3D annotations. For workcells only.
                |     ImportWclMessage: defines the option for displaying the D5 workcell
                |         messages after importing. Message is stored on the product. For workcells only.
                |     ImportCollision : defines the option for importing D5 collision queues into V5
                |         interferences objects. For workcells only.
                |     ImportFloor : defines the option for importing D5 floor into V5 Area. For workcells only.
                |     ImportUserAttr : defines the option for importing D5 user attributes into V5 knowledgeware
                |         parameters.
                |     ImportEdge : defines the option for importing D5 geometric (edge) information.
                |     ImportCoorsys : defines the option for importing D5 coorsys into V5 frames of interests
                |         (by default as DESIGN).
                |     ImportToolFrm : defines the option for importing D5 tool frame into V5 frames of interests
                |         (by default as TOOL).
                |     ImportBaseFrm : defines the option for importing D5 base frame into V5 base frames of interests
                |         (by default as BASE).
                |     ImportWclPath : defines the option for importing D5 workcell paths into V5 frames of interests
                |         (by default as MANUFACTURING).
                |     VisCoorsys : defines the visibility status at the import of D5 coorsys.
                |     VisToolFrm : defines the visibility status at the import of D5 tool frame.
                |     VisBaseFrm : defines the visibility status at the import of D5 base frame.
                |     VisWclPath : defines the visibility status at the import of D5 workcell paths.
                |     TypeCoorsys : defines the V5 frame of interest matching type when importing D5 coorsys.
                |     TypeToolFrm : defines the V5 frame of interest matching type when importing D5 tool frame.
                |     TypeBaseFrm : defines the V5 frame of interest matching type when importing D5 base frame.
                |     TypeWclPath : defines the V5 frame of interest matching type when importing D5 workcell paths.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.import_d5_setting_att = com_object

    def get_import_annotation_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetImportAnnotationInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the ImportAnnotation
                |     parameter.
                |     Role:Retrieves the state of the ImportAnnotation parameter in the current
                |     environment.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.import_d5_setting_att.GetImportAnnotationInfo(io_admin_level, io_locked)

    def get_import_base_frm_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetImportBaseFrmInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the ImportBaseFrm
                |     parameter.
                |     Role:Retrieves the state of the ImportBaseFrm parameter in the current
                |     environment.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.import_d5_setting_att.GetImportBaseFrmInfo(io_admin_level, io_locked)

    def get_import_collision_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetImportCollisionInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the ImportCollision
                |     parameter.
                |     Role:Retrieves the state of the ImportCollision parameter in the current
                |     environment.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.import_d5_setting_att.GetImportCollisionInfo(io_admin_level, io_locked)

    def get_import_config_file_expanded(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetImportConfigFileExpanded() As CATBSTR
                | 
                |     Returns the ImportConfigFile parameter (manages expanded file
                |     pathnames).
                | 
                |     Ensure consistency with the C++ interface to which the work is delegated.

        :rtype: str
        """
        return self.import_d5_setting_att.GetImportConfigFileExpanded()

    def get_import_config_file_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetImportConfigFileInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the ImportConfigFile
                |     parameter.
                |     Role:Retrieves the state of the ImportConfigFile parameter in the current
                |     environment.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.import_d5_setting_att.GetImportConfigFileInfo(io_admin_level, io_locked)

    def get_import_coorsys_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetImportCoorsysInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the ImportCoorsys
                |     parameter.
                |     Role:Retrieves the state of the ImportCoorsys parameter in the current
                |     environment.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.import_d5_setting_att.GetImportCoorsysInfo(io_admin_level, io_locked)

    def get_import_edge_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetImportEdgeInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the ImportEdge
                |     parameter.
                |     Role:Retrieves the state of the ImportEdge parameter in the current
                |     environment.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.import_d5_setting_att.GetImportEdgeInfo(io_admin_level, io_locked)

    def get_import_floor_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetImportFloorInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the ImportFloor
                |     parameter.
                |     Role:Retrieves the state of the ImportFloor parameter in the current
                |     environment.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.import_d5_setting_att.GetImportFloorInfo(io_admin_level, io_locked)

    def get_import_library_expanded(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetImportLibraryExpanded() As CATBSTR
                | 
                |     Returns the ImportLibrary parameter (manages expanded file
                |     pathnames).
                | 
                |     Ensure consistency with the C++ interface to which the work is delegated.

        :rtype: str
        """
        return self.import_d5_setting_att.GetImportLibraryExpanded()

    def get_import_library_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetImportLibraryInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the ImportLibrary
                |     parameter.
                |     Role:Retrieves the state of the ImportLibrary parameter in the current
                |     environment.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.import_d5_setting_att.GetImportLibraryInfo(io_admin_level, io_locked)

    def get_import_pdb_cache_expanded(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetImportPDBCacheExpanded() As CATBSTR
                | 
                |     Returns the ImportPDBCache parameter (manages expanded file
                |     pathnames).
                | 
                |     Ensure consistency with the C++ interface to which the work is delegated.

        :rtype: str
        """
        return self.import_d5_setting_att.GetImportPDBCacheExpanded()

    def get_import_pdb_cache_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetImportPDBCacheInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the ImportPDBCache
                |     parameter.
                |     Role:Retrieves the state of the ImportPDBCache parameter in the current
                |     environment.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.import_d5_setting_att.GetImportPDBCacheInfo(io_admin_level, io_locked)

    def get_import_recording_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetImportRecordingInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the ImportRecording
                |     parameter.
                |     Role:Retrieves the state of the ImportRecording parameter in the current
                |     environment.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.import_d5_setting_att.GetImportRecordingInfo(io_admin_level, io_locked)

    def get_import_tool_frm_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetImportToolFrmInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the ImportToolFrm
                |     parameter.
                |     Role:Retrieves the state of the ImportToolFrm parameter in the current
                |     environment.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.import_d5_setting_att.GetImportToolFrmInfo(io_admin_level, io_locked)

    def get_import_user_attr_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetImportUserAttrInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the ImportUserAttr
                |     parameter.
                |     Role:Retrieves the state of the ImportUserAttr parameter in the current
                |     environment.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.import_d5_setting_att.GetImportUserAttrInfo(io_admin_level, io_locked)

    def get_import_user_views_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetImportUserViewsInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the ImportUserViews
                |     parameter.
                |     Role:Retrieves the state of the ImportUserViews parameter in the current
                |     environment.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.import_d5_setting_att.GetImportUserViewsInfo(io_admin_level, io_locked)

    def get_import_wcl_message_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetImportWclMessageInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the ImportWclMessage
                |     parameter.
                |     Role:Retrieves the state of the ImportWclMessage parameter in the current
                |     environment.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.import_d5_setting_att.GetImportWclMessageInfo(io_admin_level, io_locked)

    def get_import_wcl_path_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetImportWclPathInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the ImportWclPath
                |     parameter.
                |     Role:Retrieves the state of the ImportWclPath parameter in the current
                |     environment.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.import_d5_setting_att.GetImportWclPathInfo(io_admin_level, io_locked)

    def get_type_base_frm_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetTypeBaseFrmInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the TypeBaseFrm
                |     parameter.
                |     Role:Retrieves the state of the TypeBaseFrm parameter in the current
                |     environment.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.import_d5_setting_att.GetTypeBaseFrmInfo(io_admin_level, io_locked)

    def get_type_coorsys_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetTypeCoorsysInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the TypeCoorsys
                |     parameter.
                |     Role:Retrieves the state of the TypeCoorsys parameter in the current
                |     environment.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.import_d5_setting_att.GetTypeCoorsysInfo(io_admin_level, io_locked)

    def get_type_tool_frm_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetTypeToolFrmInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the TypeToolFrm
                |     parameter.
                |     Role:Retrieves the state of the TypeToolFrm parameter in the current
                |     environment.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.import_d5_setting_att.GetTypeToolFrmInfo(io_admin_level, io_locked)

    def get_type_wcl_path_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetTypeWclPathInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the TypeWclPath
                |     parameter.
                |     Role:Retrieves the state of the TypeWclPath parameter in the current
                |     environment.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.import_d5_setting_att.GetTypeWclPathInfo(io_admin_level, io_locked)

    def get_vis_base_frm_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetVisBaseFrmInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the VisBaseFrm
                |     parameter.
                |     Role:Retrieves the state of the VisBaseFrm parameter in the current
                |     environment.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.import_d5_setting_att.GetVisBaseFrmInfo(io_admin_level, io_locked)

    def get_vis_coorsys_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetVisCoorsysInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the VisCoorsys
                |     parameter.
                |     Role:Retrieves the state of the VisCoorsys parameter in the current
                |     environment.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.import_d5_setting_att.GetVisCoorsysInfo(io_admin_level, io_locked)

    def get_vis_tool_frm_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetVisToolFrmInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the VisToolFrm
                |     parameter.
                |     Role:Retrieves the state of the VisToolFrm parameter in the current
                |     environment.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.import_d5_setting_att.GetVisToolFrmInfo(io_admin_level, io_locked)

    def get_vis_wcl_path_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetVisWclPathInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the VisWclPath
                |     parameter.
                |     Role:Retrieves the state of the VisWclPath parameter in the current
                |     environment.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.import_d5_setting_att.GetVisWclPathInfo(io_admin_level, io_locked)

    def set_import_annotation_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetImportAnnotationLock(boolean iLocked)
                | 
                |     Locks or unlocks the ImportAnnotation parameter.
                |     Role:Locks or unlocks the ImportAnnotation parameter if it is possible in
                |     the current administrative context. In user mode this method will always return
                |     E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter.

        :param bool i_locked:
        :rtype: None
        """
        return self.import_d5_setting_att.SetImportAnnotationLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_import_annotation_lock'
        # # vba_code = """
        # # Public Function set_import_annotation_lock(import_d5_setting_att)
        # #     Dim iLocked (2)
        # #     import_d5_setting_att.SetImportAnnotationLock iLocked
        # #     set_import_annotation_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_import_base_frm_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetImportBaseFrmLock(boolean iLocked)
                | 
                |     Locks or unlocks the ImportBaseFrm parameter.
                |     Role:Locks or unlocks the ImportBaseFrm parameter if it is possible in the
                |     current administrative context. In user mode this method will always return
                |     E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter.

        :param bool i_locked:
        :rtype: None
        """
        return self.import_d5_setting_att.SetImportBaseFrmLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_import_base_frm_lock'
        # # vba_code = """
        # # Public Function set_import_base_frm_lock(import_d5_setting_att)
        # #     Dim iLocked (2)
        # #     import_d5_setting_att.SetImportBaseFrmLock iLocked
        # #     set_import_base_frm_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_import_collision_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetImportCollisionLock(boolean iLocked)
                | 
                |     Locks or unlocks the ImportCollision parameter.
                |     Role:Locks or unlocks the ImportCollision parameter if it is possible in
                |     the current administrative context. In user mode this method will always return
                |     E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter.

        :param bool i_locked:
        :rtype: None
        """
        return self.import_d5_setting_att.SetImportCollisionLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_import_collision_lock'
        # # vba_code = """
        # # Public Function set_import_collision_lock(import_d5_setting_att)
        # #     Dim iLocked (2)
        # #     import_d5_setting_att.SetImportCollisionLock iLocked
        # #     set_import_collision_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_import_config_file_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetImportConfigFileLock(boolean iLocked)
                | 
                |     Locks or unlocks the ImportConfigFile parameter.
                |     Role:Locks or unlocks the ImportConfigFile parameter if it is possible in
                |     the current administrative context. In user mode this method will always return
                |     E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter.

        :param bool i_locked:
        :rtype: None
        """
        return self.import_d5_setting_att.SetImportConfigFileLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_import_config_file_lock'
        # # vba_code = """
        # # Public Function set_import_config_file_lock(import_d5_setting_att)
        # #     Dim iLocked (2)
        # #     import_d5_setting_att.SetImportConfigFileLock iLocked
        # #     set_import_config_file_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_import_coorsys_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetImportCoorsysLock(boolean iLocked)
                | 
                |     Locks or unlocks the ImportCoorsys parameter.
                |     Role:Locks or unlocks the ImportCoorsys parameter if it is possible in the
                |     current administrative context. In user mode this method will always return
                |     E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter.

        :param bool i_locked:
        :rtype: None
        """
        return self.import_d5_setting_att.SetImportCoorsysLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_import_coorsys_lock'
        # # vba_code = """
        # # Public Function set_import_coorsys_lock(import_d5_setting_att)
        # #     Dim iLocked (2)
        # #     import_d5_setting_att.SetImportCoorsysLock iLocked
        # #     set_import_coorsys_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_import_edge_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetImportEdgeLock(boolean iLocked)
                | 
                |     Locks or unlocks the ImportEdge parameter.
                |     Role:Locks or unlocks the ImportEdge parameter if it is possible in the
                |     current administrative context. In user mode this method will always return
                |     E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter.

        :param bool i_locked:
        :rtype: None
        """
        return self.import_d5_setting_att.SetImportEdgeLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_import_edge_lock'
        # # vba_code = """
        # # Public Function set_import_edge_lock(import_d5_setting_att)
        # #     Dim iLocked (2)
        # #     import_d5_setting_att.SetImportEdgeLock iLocked
        # #     set_import_edge_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_import_floor_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetImportFloorLock(boolean iLocked)
                | 
                |     Locks or unlocks the ImportFloor parameter.
                |     Role:Locks or unlocks the ImportFloor parameter if it is possible in the
                |     current administrative context. In user mode this method will always return
                |     E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter.

        :param bool i_locked:
        :rtype: None
        """
        return self.import_d5_setting_att.SetImportFloorLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_import_floor_lock'
        # # vba_code = """
        # # Public Function set_import_floor_lock(import_d5_setting_att)
        # #     Dim iLocked (2)
        # #     import_d5_setting_att.SetImportFloorLock iLocked
        # #     set_import_floor_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_import_library_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetImportLibraryLock(boolean iLocked)
                | 
                |     Locks or unlocks the ImportLibrary parameter.
                |     Role:Locks or unlocks the ImportLibrary parameter if it is possible in the
                |     current administrative context. In user mode this method will always return
                |     E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter.

        :param bool i_locked:
        :rtype: None
        """
        return self.import_d5_setting_att.SetImportLibraryLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_import_library_lock'
        # # vba_code = """
        # # Public Function set_import_library_lock(import_d5_setting_att)
        # #     Dim iLocked (2)
        # #     import_d5_setting_att.SetImportLibraryLock iLocked
        # #     set_import_library_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_import_pdb_cache_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetImportPDBCacheLock(boolean iLocked)
                | 
                |     Locks or unlocks the ImportPDBCache parameter.
                |     Role:Locks or unlocks the ImportPDBCache parameter if it is possible in the
                |     current administrative context. In user mode this method will always return
                |     E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter.

        :param bool i_locked:
        :rtype: None
        """
        return self.import_d5_setting_att.SetImportPDBCacheLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_import_pdb_cache_lock'
        # # vba_code = """
        # # Public Function set_import_pdb_cache_lock(import_d5_setting_att)
        # #     Dim iLocked (2)
        # #     import_d5_setting_att.SetImportPDBCacheLock iLocked
        # #     set_import_pdb_cache_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_import_recording_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetImportRecordingLock(boolean iLocked)
                | 
                |     Locks or unlocks the ImportRecording parameter.
                |     Role:Locks or unlocks the ImportRecording parameter if it is possible in
                |     the current administrative context. In user mode this method will always return
                |     E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter.

        :param bool i_locked:
        :rtype: None
        """
        return self.import_d5_setting_att.SetImportRecordingLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_import_recording_lock'
        # # vba_code = """
        # # Public Function set_import_recording_lock(import_d5_setting_att)
        # #     Dim iLocked (2)
        # #     import_d5_setting_att.SetImportRecordingLock iLocked
        # #     set_import_recording_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_import_tool_frm_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetImportToolFrmLock(boolean iLocked)
                | 
                |     Locks or unlocks the ImportToolFrm parameter.
                |     Role:Locks or unlocks the ImportToolFrm parameter if it is possible in the
                |     current administrative context. In user mode this method will always return
                |     E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter.

        :param bool i_locked:
        :rtype: None
        """
        return self.import_d5_setting_att.SetImportToolFrmLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_import_tool_frm_lock'
        # # vba_code = """
        # # Public Function set_import_tool_frm_lock(import_d5_setting_att)
        # #     Dim iLocked (2)
        # #     import_d5_setting_att.SetImportToolFrmLock iLocked
        # #     set_import_tool_frm_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_import_user_attr_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetImportUserAttrLock(boolean iLocked)
                | 
                |     Locks or unlocks the ImportUserAttr parameter.
                |     Role:Locks or unlocks the ImportUserAttr parameter if it is possible in the
                |     current administrative context. In user mode this method will always return
                |     E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter.

        :param bool i_locked:
        :rtype: None
        """
        return self.import_d5_setting_att.SetImportUserAttrLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_import_user_attr_lock'
        # # vba_code = """
        # # Public Function set_import_user_attr_lock(import_d5_setting_att)
        # #     Dim iLocked (2)
        # #     import_d5_setting_att.SetImportUserAttrLock iLocked
        # #     set_import_user_attr_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_import_user_views_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetImportUserViewsLock(boolean iLocked)
                | 
                |     Locks or unlocks the ImportUserViews parameter.
                |     Role:Locks or unlocks the ImportUserViews parameter if it is possible in
                |     the current administrative context. In user mode this method will always return
                |     E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter.

        :param bool i_locked:
        :rtype: None
        """
        return self.import_d5_setting_att.SetImportUserViewsLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_import_user_views_lock'
        # # vba_code = """
        # # Public Function set_import_user_views_lock(import_d5_setting_att)
        # #     Dim iLocked (2)
        # #     import_d5_setting_att.SetImportUserViewsLock iLocked
        # #     set_import_user_views_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_import_wcl_message_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetImportWclMessageLock(boolean iLocked)
                | 
                |     Locks or unlocks the ImportWclMessage parameter.
                |     Role:Locks or unlocks the ImportWclMessage parameter if it is possible in
                |     the current administrative context. In user mode this method will always return
                |     E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter.

        :param bool i_locked:
        :rtype: None
        """
        return self.import_d5_setting_att.SetImportWclMessageLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_import_wcl_message_lock'
        # # vba_code = """
        # # Public Function set_import_wcl_message_lock(import_d5_setting_att)
        # #     Dim iLocked (2)
        # #     import_d5_setting_att.SetImportWclMessageLock iLocked
        # #     set_import_wcl_message_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_import_wcl_path_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetImportWclPathLock(boolean iLocked)
                | 
                |     Locks or unlocks the ImportWclPath parameter.
                |     Role:Locks or unlocks the ImportWclPath parameter if it is possible in the
                |     current administrative context. In user mode this method will always return
                |     E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter.

        :param bool i_locked:
        :rtype: None
        """
        return self.import_d5_setting_att.SetImportWclPathLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_import_wcl_path_lock'
        # # vba_code = """
        # # Public Function set_import_wcl_path_lock(import_d5_setting_att)
        # #     Dim iLocked (2)
        # #     import_d5_setting_att.SetImportWclPathLock iLocked
        # #     set_import_wcl_path_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_type_base_frm_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetTypeBaseFrmLock(boolean iLocked)
                | 
                |     Locks or unlocks the TypeBaseFrm parameter.
                |     Role:Locks or unlocks the TypeBaseFrm parameter if it is possible in the
                |     current administrative context. In user mode this method will always return
                |     E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter.

        :param bool i_locked:
        :rtype: None
        """
        return self.import_d5_setting_att.SetTypeBaseFrmLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_type_base_frm_lock'
        # # vba_code = """
        # # Public Function set_type_base_frm_lock(import_d5_setting_att)
        # #     Dim iLocked (2)
        # #     import_d5_setting_att.SetTypeBaseFrmLock iLocked
        # #     set_type_base_frm_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_type_coorsys_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetTypeCoorsysLock(boolean iLocked)
                | 
                |     Locks or unlocks the TypeCoorsys parameter.
                |     Role:Locks or unlocks the TypeCoorsys parameter if it is possible in the
                |     current administrative context. In user mode this method will always return
                |     E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter.

        :param bool i_locked:
        :rtype: None
        """
        return self.import_d5_setting_att.SetTypeCoorsysLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_type_coorsys_lock'
        # # vba_code = """
        # # Public Function set_type_coorsys_lock(import_d5_setting_att)
        # #     Dim iLocked (2)
        # #     import_d5_setting_att.SetTypeCoorsysLock iLocked
        # #     set_type_coorsys_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_type_tool_frm_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetTypeToolFrmLock(boolean iLocked)
                | 
                |     Locks or unlocks the TypeToolFrm parameter.
                |     Role:Locks or unlocks the TypeToolFrm parameter if it is possible in the
                |     current administrative context. In user mode this method will always return
                |     E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter.

        :param bool i_locked:
        :rtype: None
        """
        return self.import_d5_setting_att.SetTypeToolFrmLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_type_tool_frm_lock'
        # # vba_code = """
        # # Public Function set_type_tool_frm_lock(import_d5_setting_att)
        # #     Dim iLocked (2)
        # #     import_d5_setting_att.SetTypeToolFrmLock iLocked
        # #     set_type_tool_frm_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_type_wcl_path_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetTypeWclPathLock(boolean iLocked)
                | 
                |     Locks or unlocks the TypeWclPath parameter.
                |     Role:Locks or unlocks the TypeWclPath parameter if it is possible in the
                |     current administrative context. In user mode this method will always return
                |     E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter.

        :param bool i_locked:
        :rtype: None
        """
        return self.import_d5_setting_att.SetTypeWclPathLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_type_wcl_path_lock'
        # # vba_code = """
        # # Public Function set_type_wcl_path_lock(import_d5_setting_att)
        # #     Dim iLocked (2)
        # #     import_d5_setting_att.SetTypeWclPathLock iLocked
        # #     set_type_wcl_path_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_vis_base_frm_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetVisBaseFrmLock(boolean iLocked)
                | 
                |     Locks or unlocks the VisBaseFrm parameter.
                |     Role:Locks or unlocks the VisBaseFrm parameter if it is possible in the
                |     current administrative context. In user mode this method will always return
                |     E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter.

        :param bool i_locked:
        :rtype: None
        """
        return self.import_d5_setting_att.SetVisBaseFrmLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_vis_base_frm_lock'
        # # vba_code = """
        # # Public Function set_vis_base_frm_lock(import_d5_setting_att)
        # #     Dim iLocked (2)
        # #     import_d5_setting_att.SetVisBaseFrmLock iLocked
        # #     set_vis_base_frm_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_vis_coorsys_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetVisCoorsysLock(boolean iLocked)
                | 
                |     Locks or unlocks the VisCoorsys parameter.
                |     Role:Locks or unlocks the VisCoorsys parameter if it is possible in the
                |     current administrative context. In user mode this method will always return
                |     E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter.

        :param bool i_locked:
        :rtype: None
        """
        return self.import_d5_setting_att.SetVisCoorsysLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_vis_coorsys_lock'
        # # vba_code = """
        # # Public Function set_vis_coorsys_lock(import_d5_setting_att)
        # #     Dim iLocked (2)
        # #     import_d5_setting_att.SetVisCoorsysLock iLocked
        # #     set_vis_coorsys_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_vis_tool_frm_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetVisToolFrmLock(boolean iLocked)
                | 
                |     Locks or unlocks the VisToolFrm parameter.
                |     Role:Locks or unlocks the VisToolFrm parameter if it is possible in the
                |     current administrative context. In user mode this method will always return
                |     E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter.

        :param bool i_locked:
        :rtype: None
        """
        return self.import_d5_setting_att.SetVisToolFrmLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_vis_tool_frm_lock'
        # # vba_code = """
        # # Public Function set_vis_tool_frm_lock(import_d5_setting_att)
        # #     Dim iLocked (2)
        # #     import_d5_setting_att.SetVisToolFrmLock iLocked
        # #     set_vis_tool_frm_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_vis_wcl_path_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetVisWclPathLock(boolean iLocked)
                | 
                |     Locks or unlocks the VisWclPath parameter.
                |     Role:Locks or unlocks the VisWclPath parameter if it is possible in the
                |     current administrative context. In user mode this method will always return
                |     E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter.

        :param bool i_locked:
        :rtype: None
        """
        return self.import_d5_setting_att.SetVisWclPathLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_vis_wcl_path_lock'
        # # vba_code = """
        # # Public Function set_vis_wcl_path_lock(import_d5_setting_att)
        # #     Dim iLocked (2)
        # #     import_d5_setting_att.SetVisWclPathLock iLocked
        # #     set_vis_wcl_path_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def __repr__(self):
        return f'ImportD5SettingAtt(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-07-06 14:02:20.222384

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.hybrid_shape_interfaces.line import Line
from pycatia.in_interfaces.reference import Reference
from pycatia.knowledge_interfaces.length import Length


class HybridShapeLineNormal(Line):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     MecModInterfaces.HybridShape
                |                         CATGSMIDLItf.Line
                |                             HybridShapeLineNormal
                | 
                | Line defined by a point and a direction normal to a surface.
                | Role: To access data of the line feature created by using the normal direction
                | of a surface
                | 
                | Use the CATIAHybridShapeFactory to create a HybridShapeLineNormal
                | object.
                | 
                | See also:
                |     Reference 
                | See also:
                |     Length 
                | See also:
                |     HybridShapeDirection 
                | See also:
                |     HybridShapeFactory
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.hybrid_shape_line_normal = com_object

    @property
    def begin_offset(self) -> Length:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property BeginOffset() As Length (Read Only)
                | 
                |     Returns the start length of the line.
                |     Start length : extension of the line, beginning at the starting point
                | 
                |     Example:
                |         This example retrieves in oStart the beginning offset length for the
                |         LineNormal hybrid shape feature.
                | 
                |          Dim oStart As  CATIALength 
                |          Set oStart = LineNormal.BeginOffset

        :rtype: Length
        """

        return Length(self.hybrid_shape_line_normal.BeginOffset)

    @property
    def end_offset(self) -> Length:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property EndOffset() As Length (Read Only)
                | 
                |     Returns the end length of the line.
                |     End length : extension of the line, beginning at the ending point
                | 
                |     Example:
                |         This example retrieves in oEnd the starting length for the LineNormal
                |         hybrid shape feature.
                | 
                |          Dim oEnd As  CATIALength 
                |          Set oEnd = LineNormal.EndOffset

        :rtype: Length
        """

        return Length(self.hybrid_shape_line_normal.EndOffset)

    @property
    def orientation(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property Orientation() As long
                | 
                |     Returns or Sets the line orientation.
                |     Orientation allows to reverse the line direction from the reference
                |     point.
                |     For a line of L length, it is the same as creating this line with -L length :
                |     Orientation : can be 1 or -1
                | 
                |     Example:
                |         This example retrieves in oOrientation the starting length for the
                |         LineNormal hybrid shape feature.
                | 
                |          Dim oOrientation As long
                |          Set oOrientation = LineNormal.Orientation

        :rtype: int
        """

        return self.hybrid_shape_line_normal.Orientation

    @orientation.setter
    def orientation(self, value: int):
        """
        :param int value:
        """

        self.hybrid_shape_line_normal.Orientation = value

    @property
    def point(self) -> Reference:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property Point() As Reference
                | 
                |     Returns or Sets the starting point of the line.
                |     Sub-element(s) supported (see Boundary object): Vertex.
                | 
                |     Example:
                |         This example retrieves in oPoint the starting point for the LineNormal
                |         hybrid shape feature.
                | 
                |          Dim oPoint As Reference
                |          Set oPoint = LineNormal.Point

        :rtype: Reference
        """

        return Reference(self.hybrid_shape_line_normal.Point)

    @point.setter
    def point(self, reference_point: Reference):
        """
        :param Reference reference_point:
        """

        self.hybrid_shape_line_normal.Point = reference_point.com_object

    @property
    def surface(self) -> Reference:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property Surface() As Reference
                | 
                |     Returns or Sets the surface to which the line will be
                |     normal.
                |     Sub-element(s) supported (see Boundary object): Face.
                | 
                |     Example:
                |         This example retrieves in oSurface the surface for the LineNormal
                |         hybrid shape feature.
                | 
                |          Dim oSurface As Reference 
                |          Set oSurface = LineNormal.Surface

        :rtype: Reference
        """

        return Reference(self.hybrid_shape_line_normal.Surface)

    @surface.setter
    def surface(self, surface_reference: Reference):
        """
        :param Reference surface_reference:
        """

        self.hybrid_shape_line_normal.Surface = surface_reference.com_object

    def get_length_type(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Func GetLengthType() As long
                | 
                |     Gets the length type Default is 0.
                | 
                |     Parameters:
                | 
                |         oType
                |             The length type = 0 : length - the line is limited by its extremities =
                |             1 : infinite - the line is infinite = 2 : infinite start point - the line is infinite on
                |             the side of the start point = 3 : infinite end point - the line is infinite on the side
                |             of the end point

        :rtype: int
        """
        return self.hybrid_shape_line_normal.GetLengthType()

    def get_symmetrical_extension(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Func GetSymmetricalExtension() As boolean
                | 
                |     Gets whether the symmetrical extension of the line is
                |     active.
                | 
                |     Parameters:
                | 
                |         oSym
                |             Symetry flag

        :rtype: bool
        """
        return self.hybrid_shape_line_normal.GetSymmetricalExtension()

    def set_length_type(self, i_type: int) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub SetLengthType(long iType)
                | 
                |     Sets the length type Default is 0.
                | 
                |     Parameters:
                | 
                |         iType
                |             The length type = 0 : length - the line is limited by its extremities =
                |             1 : infinite - the line is infinite =
                |             2 : infinite start point - the line is infinite on the side of the start point =
                |             3 : infinite end point - the line is infinite on the side of the end point

        :param int i_type:
        :rtype: None
        """
        return self.hybrid_shape_line_normal.SetLengthType(i_type)

    def set_symmetrical_extension(self, i_sym: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub SetSymmetricalExtension(boolean iSym)
                | 
                |     Sets the symmetrical extension of the line (start = -end).
                | 
                |     Parameters:
                | 
                |         iSym
                |             Symetry flag

        :param bool i_sym:
        :rtype: None
        """
        return self.hybrid_shape_line_normal.SetSymmetricalExtension(i_sym)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_symmetrical_extension'
        # # vba_code = """
        # # Public Function set_symmetrical_extension(hybrid_shape_line_normal)
        # #     Dim iSym (2)
        # #     hybrid_shape_line_normal.SetSymmetricalExtension iSym
        # #     set_symmetrical_extension = iSym
        # # End Function
        # # """

        # # system_service = self.application.system_service
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def __repr__(self):
        return f'HybridShapeLineNormal(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.system_interfaces.any_object import AnyObject
from pycatia.types.general import cat_variant


class ARCTagGroup(AnyObject):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     ARCTagGroup
                | 
                | Interface representing a Tag.
                | 
                | Role: This interface is used to work with ARCTagGroup.
                | The following code snippet can be used to obtain a Tag from a selected
                | Product
                | 
                |   Set ParentObject = CATIA.ActiveDocument.Selection.FindObject("CATIAProduct")	
                |   Set objTag = ParentObject.GetTechnologicalObject("Tag")
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.arc_tag_group = com_object

    def compute_distance_along_seam(self, i_first_tag_idx: int, i_second_tag_idx: int, o_distance: float) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub ComputeDistanceAlongSeam(short iFirstTagIdx,
                | short iSecondTagIdx,
                | double oDistance)
                | 
                |     Function to compute the distance along the seam between two ARC tags of the
                |     ARCTagGroup.
                | 
                |     Parameters:
                | 
                |         iFirstTagIdx
                |             the index of the first tag. 
                |         iSecondTagIdx
                |             the index of the second tag. 
                |         oDistance
                |             the computed distance along the seam. 
                | 
                |     Returns:
                |         an HRESULT value.
                |         Legal values:
                | 
                |             S_OK if the operation succeeds
                |             E_FAIL otherwise.

        :param int i_first_tag_idx:
        :param int i_second_tag_idx:
        :param float o_distance:
        :rtype: None
        """
        return self.arc_tag_group.ComputeDistanceAlongSeam(i_first_tag_idx, i_second_tag_idx, o_distance)

    def get_arc_tags_list(self, o_arc_tag_list: tuple) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub GetARCTagsList(CATSafeArrayVariant oARCTagList)
                | 
                |     Function to get all the ARC tags grouped by the
                |     ARCTagGroup.
                | 
                |     Parameters:
                | 
                |         oARCTagList
                |             the ARC tags list. 
                | 
                |     Returns:
                |         an HRESULT value.
                |         Legal values:
                | 
                |             S_OK if the operation succeeds
                |             E_FAIL otherwise.

        :param tuple o_arc_tag_list:
        :rtype: None
        """
        return self.arc_tag_group.GetARCTagsList(o_arc_tag_list)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'get_arc_tags_list'
        # # vba_code = """
        # # Public Function get_arc_tags_list(arc_tag_group)
        # #     Dim oARCTagList (2)
        # #     arc_tag_group.GetARCTagsList oARCTagList
        # #     get_arc_tags_list = oARCTagList
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def get_num_arc_tags(self, o_size: int) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub GetNumARCTags(short oSize)
                | 
                |     Function to get the total number of ARC tags grouped by the
                |     ARCTagGroup.
                | 
                |     Parameters:
                | 
                |         oSize
                |             the total number of ARC tags grouped by the ARCTagGroup.
                |
                |     Returns:
                |         an HRESULT value.
                |         Legal values:
                | 
                |             S_OK if the operation succeeds
                |             E_FAIL otherwise.

        :param int o_size:
        :rtype: None
        """
        return self.arc_tag_group.GetNumARCTags(o_size)

    def get_tag_group(self, o_tag_group: cat_variant) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub GetTagGroup(CATVariant oTagGroup)
                | 
                |     Function to get the underlying basic TagGroup.
                | 
                |     Parameters:
                | 
                |         oTagGroup
                |             the underlying basic TagGroup. 
                | 
                |     Returns:
                |         an HRESULT value.
                |         Legal values:
                | 
                |             S_OK if the operation succeeds
                |             E_FAIL otherwise.

        :param cat_variant o_tag_group:
        :rtype: None
        """
        return self.arc_tag_group.GetTagGroup(o_tag_group)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'get_tag_group'
        # # vba_code = """
        # # Public Function get_tag_group(arc_tag_group)
        # #     Dim oTagGroup (2)
        # #     arc_tag_group.GetTagGroup oTagGroup
        # #     get_tag_group = oTagGroup
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def get_tag_param(self, i_idx: int, i_param_name: str, o_val: float) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub GetTagParam(short iIdx,
                | CATBSTR iParamName,
                | double oVal)
                | 
                |     Function to get the value of a given ARC tag parameter. The concerned ARC
                |     tag's index should be given.
                | 
                |     Parameters:
                | 
                |         iIdx
                |             the index of the ARC tag in the ARCTagGroup. 
                |         iParamName
                |             the name of the ARC tag parameter. Following ARC tag parameters can
                |             be set: "WireAngle", "FlareAngle", "RakeAngle", "WireRollAngle",
                |             "BaseTangentOffset", "WallTangentOffset", "ShiftDistance", "FlareLength",
                |             "StickOut", "TCPStickOut", "NearDistance" 
                |         oVal
                |             the value of the ARC tag parameter. 
                | 
                |     Returns:
                |         an HRESULT value.
                |         Legal values:
                | 
                |             S_OK if the operation succeeds
                |             E_FAIL otherwise.

        :param int i_idx:
        :param str i_param_name:
        :param float o_val:
        :rtype: None
        """
        return self.arc_tag_group.GetTagParam(i_idx, i_param_name, o_val)

    def rotate_tag(self, i_idx: int, i_angle: float, i_dir_vector: tuple) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub RotateTag(short iIdx,
                | double iAngle,
                | CATSafeArrayVariant iDirVector)
                | 
                |     Function to rotate the ARC tag with the given index about the given
                |     direction vector.
                | 
                |     Parameters:
                | 
                |         iIdx
                |             the index of the ARC tag in the ARCTagGroup. 
                |         iAngle
                |             the angle by which the ARC tag should be rotated about the given
                |             direction vector. 
                |         iDirVector
                |             the direction vector( array of 3 real values ). 
                | 
                |     Returns:
                |         an HRESULT value.
                |         Legal values:
                | 
                |             S_OK if the operation succeeds
                |             E_FAIL otherwise.

        :param int i_idx:
        :param float i_angle:
        :param tuple i_dir_vector:
        :rtype: None
        """
        return self.arc_tag_group.RotateTag(i_idx, i_angle, i_dir_vector)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'rotate_tag'
        # # vba_code = """
        # # Public Function rotate_tag(arc_tag_group)
        # #     Dim iIdx (2)
        # #     arc_tag_group.RotateTag iIdx
        # #     rotate_tag = iIdx
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def rotate_x_tag(self, i_idx: int, i_angle: float) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub RotateXTag(short iIdx,
                | double iAngle)
                | 
                |     Function to rotate the ARC tag with the given index about it's
                |     x-axis.
                | 
                |     Parameters:
                | 
                |         iIdx
                |             the index of the ARC tag in the ARCTagGroup. 
                |         iAngle
                |             the angle by which the ARC tag should be rotated about it's x-axis.
                |             
                | 
                |     Returns:
                |         an HRESULT value.
                |         Legal values:
                | 
                |             S_OK if the operation succeeds
                |             E_FAIL otherwise.

        :param int i_idx:
        :param float i_angle:
        :rtype: None
        """
        return self.arc_tag_group.RotateXTag(i_idx, i_angle)

    def rotate_y_tag(self, i_idx: int, i_angle: float) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub RotateYTag(short iIdx,
                | double iAngle)
                | 
                |     Function to rotate the ARC tag with the given index about it's
                |     y-axis.
                | 
                |     Parameters:
                | 
                |         iIdx
                |             the index of the ARC tag in the ARCTagGroup. 
                |         iAngle
                |             the angle by which the ARC tag should be rotated about it's y-axis.
                |             
                | 
                |     Returns:
                |         an HRESULT value.
                |         Legal values:
                | 
                |             S_OK if the operation succeeds
                |             E_FAIL otherwise.

        :param int i_idx:
        :param float i_angle:
        :rtype: None
        """
        return self.arc_tag_group.RotateYTag(i_idx, i_angle)

    def rotate_z_tag(self, i_idx: int, i_angle: float) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub RotateZTag(short iIdx,
                | double iAngle)
                | 
                |     Function to rotate the ARC tag with the given index about it's
                |     z-axis.
                | 
                |     Parameters:
                | 
                |         iIdx
                |             the index of the ARC tag in the ARCTagGroup. 
                |         iAngle
                |             the angle by which the ARC tag should be rotated about it's z-axis.
                |             
                | 
                |     Returns:
                |         an HRESULT value.
                |         Legal values:
                | 
                |             S_OK if the operation succeeds
                |             E_FAIL otherwise.

        :param int i_idx:
        :param float i_angle:
        :rtype: None
        """
        return self.arc_tag_group.RotateZTag(i_idx, i_angle)

    def set_tag_param(self, i_idx: int, i_param_name: str, i_val: float) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetTagParam(short iIdx,
                | CATBSTR iParamName,
                | double iVal)
                | 
                |     Function to set the value of a given ARC tag parameter. The concerned ARC
                |     tag's index should be given.
                | 
                |     Parameters:
                | 
                |         iIdx
                |             the index of the ARC tag in the ARCTagGroup. 
                |         iParamName
                |             the name of the ARC tag parameter. Following ARC tag parameters can
                |             be set: "WireAngle", "FlareAngle", "RakeAngle", "WireRollAngle",
                |             "BaseTangentOffset", "WallTangentOffset", "ShiftDistance", "FlareLength",
                |             "StickOut", "TCPStickOut", "NearDistance" 
                |         iVal
                |             the value of the ARC tag parameter. 
                | 
                |     Returns:
                |         an HRESULT value.
                |         Legal values:
                | 
                |             S_OK if the operation succeeds
                |             E_FAIL otherwise.

        :param int i_idx:
        :param str i_param_name:
        :param float i_val:
        :rtype: None
        """
        return self.arc_tag_group.SetTagParam(i_idx, i_param_name, i_val)

    def translate_tag(self, i_idx: int, i_distance: float, i_dir_vector: tuple) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub TranslateTag(short iIdx,
                | double iDistance,
                | CATSafeArrayVariant iDirVector)
                | 
                |     Function to translate the ARC tag with the given index along the given
                |     direction vector.
                | 
                |     Parameters:
                | 
                |         iIdx
                |             the index of the ARC tag in the ARCTagGroup. 
                |         iDistance
                |             the distance by which the ARC tag should be translated along the
                |             given direction vector. 
                |         iDirVector
                |             the direction vector( array of 3 real values ). 
                | 
                |     Returns:
                |         an HRESULT value.
                |         Legal values:
                | 
                |             S_OK if the operation succeeds
                |             E_FAIL otherwise.

        :param int i_idx:
        :param float i_distance:
        :param tuple i_dir_vector:
        :rtype: None
        """
        return self.arc_tag_group.TranslateTag(i_idx, i_distance, i_dir_vector)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'translate_tag'
        # # vba_code = """
        # # Public Function translate_tag(arc_tag_group)
        # #     Dim iIdx (2)
        # #     arc_tag_group.TranslateTag iIdx
        # #     translate_tag = iIdx
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def translate_tag_along_seam(self, i_idx: int, i_distance: float) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub TranslateTagAlongSeam(short iIdx,
                | double iDistance)
                | 
                |     Function to translate the ARC tag with the given index along the
                |     seam.
                | 
                |     Parameters:
                | 
                |         iIdx
                |             the index of the ARC tag in the ARCTagGroup. 
                |         iDistance
                |             the distance by which the ARC tag should be translated along the
                |             seam. 
                | 
                |     Returns:
                |         an HRESULT value.
                |         Legal values:
                | 
                |             S_OK if the operation succeeds
                |             E_FAIL otherwise.

        :param int i_idx:
        :param float i_distance:
        :rtype: None
        """
        return self.arc_tag_group.TranslateTagAlongSeam(i_idx, i_distance)

    def __repr__(self):
        return f'ARCTagGroup(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.abq_automation_interfaces.abq_temperature import ABQTemperature
from pycatia.system_interfaces.collection import Collection
from pycatia.types.general import cat_variant


class ABQFields(Collection):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.Collection
                |                     ABQFields
                | 
                | The collection of Abaqus field (ABQTemperature) objects contained
                | in
                | ABQInitialStep and ABQGeneralStaticStep and ABQExplicitDynamicsStep
                | objects.
    
    """

    def __init__(self, com_object):
        """
        Please note: The child object was guessed here as I'm unfamiliar with this module.
        """
        super().__init__(com_object, child_object=ABQTemperature)
        self.abq_fields = com_object

    def add(self, i_field_type: str) -> ABQTemperature:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func Add(CATBSTR iFieldType) As ABQTemperature
                | 
                |     Creates a new Abaqus field and adds it to the collection of Abaqus fields.
                |     The ABQInitialTemperature object can be created only in an ABQFields collection
                |     obtained from ABQInitialStep. Similarly the ABQTemperatureHistory object can be
                |     created only in an ABQFields collection obtained from
                |     ABQGeneralStaticStep.
                | 
                |     Parameters:
                | 
                |         iFieldType
                |             The type of the field to create.
                | 
                |             Legal values:
                | 
                |             "ABQInitialTemperature"
                |             "ABQTemperatureHistory"
                | 
                |     Returns:
                |         oTemperature The Abaqus field object that was created.
                |         
                |     Example:
                |         The following example creates an initial temperature in the ABQFields
                |         collection obtained from the ABQInitialStep type
                |         object:
                | 
                |          Dim abqInitialStep As ABQInitialStep
                |          Dim abqFields As ABQIAABQFields
                |          Dim abqInitalTemp As ABQTemperature
                |          Set abqFields = abqInitialStep.Fields
                |          Set abqInitalTemp =  abqFields.Add("ABQInitialTemperature")

        :param str i_field_type:
        :rtype: ABQTemperature
        """
        return ABQTemperature(self.abq_fields.Add(i_field_type))

    def item(self, i_index: cat_variant) -> ABQTemperature:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func Item(CATVariant iIndex) As ABQTemperature
                | 
                |     Returns an Abaqus field using its index or its name from the ABQFields
                |     collection.
                | 
                |     Parameters:
                | 
                |         iIndex
                |             The index or the name of the Abaqus field to retrieve from the
                |             collection of Abaqus fields. If the index is a number, it specifies the rank of
                |             the Abaqus field in the collection. The index of the first Abaqus field in the
                |             collection is 1, and the index of the last field is Count. If the index is a
                |             string, it specifies the name you assigned to the field using the
                |             CATIACollection::Name property. 
                | 
                |     Returns:
                |         The specified ABQTemperature.

        :param cat_variant i_index:
        :rtype: ABQTemperature
        """
        return ABQTemperature(self.abq_fields.Item(i_index))

    def remove(self, i_index: cat_variant) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub Remove(CATVariant iIndex)
                | 
                |     Removes an Abaqus field using its index or its name from the field
                |     collection.
                | 
                |     Parameters:
                | 
                |         iIndex
                |             The index or the name of the Abaqus field to retrieve from the
                |             collection of Abaqus Fields. If the index is a number, it specifies the rank of
                |             the Abaqus field in the collection. The index of the first Abaqus field in the
                |             collection is 1, and the index of the last field is Count. If the index is a
                |             string, it specifies the name you assigned to the field using the
                |             CATIABase::Name property.

        :param cat_variant i_index:
        :rtype: None
        """
        return self.abq_fields.Remove(i_index)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'remove'
        # # vba_code = """
        # # Public Function remove(abq_fields)
        # #     Dim iIndex (2)
        # #     abq_fields.Remove iIndex
        # #     remove = iIndex
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def __repr__(self):
        return f'ABQFields(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.cat_sch_platform_interfaces.sch_app_connector import SchAppConnector
from pycatia.system_interfaces.any_object import AnyObject


class SchCntrDocLink(AnyObject):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     SchCntrDocLink
                | 
                | Manage the on-off sheet connector.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.sch_cntr_doc_link = com_object

    def get_link(self, o_sch_connector: SchAppConnector, o_document_name: str) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub GetLink(SchAppConnector oSchConnector,
                | CATBSTR oDocumentName)
                | 
                |     Get the linked connector and its document name.
                | 
                |     Parameters:
                | 
                |         oSchConnector
                |             The connector that is linked to this connector. 
                |         oDocumentName
                |             Name of document containing the linked connector. 
                | 
                |     Example:
                |
                |          Dim objThisIntf As SchCntrDocLink
                |          Dim objArg1 As SchAppConnector
                |          Dim strVar2 As String
                |           ...
                |          objThisIntf.GetLinkobjArg1,strVar2

        :param SchAppConnector o_sch_connector:
        :param str o_document_name:
        :rtype: None
        """
        return self.sch_cntr_doc_link.GetLink(o_sch_connector.com_object, o_document_name)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'get_link'
        # # vba_code = """
        # # Public Function get_link(sch_cntr_doc_link)
        # #     Dim oSchConnector (2)
        # #     sch_cntr_doc_link.GetLink oSchConnector
        # #     get_link = oSchConnector
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def link(self, i_sch_connector: SchAppConnector) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub Link(SchAppConnector iSchConnector)
                | 
                |     Create an external link to another connector.
                | 
                |     Parameters:
                | 
                |         iSchConnector
                |             The connector to link to. 
                | 
                |     Example:
                |
                |          Dim objThisIntf As SchCntrDocLink
                |          Dim objArg1 As SchAppConnector
                |           ...
                |          objThisIntf.LinkobjArg1

        :param SchAppConnector i_sch_connector:
        :rtype: None
        """
        return self.sch_cntr_doc_link.Link(i_sch_connector.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'link'
        # # vba_code = """
        # # Public Function link(sch_cntr_doc_link)
        # #     Dim iSchConnector (2)
        # #     sch_cntr_doc_link.Link iSchConnector
        # #     link = iSchConnector
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def un_link(self) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub UnLink()
                | 
                |     Remove external link to another connector.
                | 
                |     Example:
                | 
                |           
                | 
                |          Dim objThisIntf As SchCntrDocLink
                |           ...
                |          objThisIntf.UnLink

        :rtype: None
        """
        return self.sch_cntr_doc_link.UnLink()

    def __repr__(self):
        return f'SchCntrDocLink(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.knowledge_interfaces.parameter import Parameter
from pycatia.system_interfaces.any_object import AnyObject


class ManufacturingFeature(AnyObject):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     ManufacturingFeature
                | 
                | ManufacturingFeature defines a set of methods to access a Manufacturing
                | Feature.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.manufacturing_feature = com_object

    def get_a_geometric_attribute(self, i_attribute: str) -> Parameter:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetAGeometricAttribute(CATBSTR iAttribut) As
                | Parameter
                | 
                |     Retrieve a geometry attribute of a Manufacturing Feature from its
                |     name.
                | 
                |     Parameters:
                | 
                |         iAttribute
                |             The identifier of the attribute to be read 
                |         Example:
                |             The following example retrieves the attribute 'MfgHoleExtension' of
                |             the manufacturing feature mfgFeature:
                | 
                |              call mfgFeature.GetAGeometricAttribute('MfgHoleExtension'
                |              ,ExtentParm)

        :param str i_attribute:
        :rtype: Parameter
        """
        return Parameter(self.manufacturing_feature.GetAGeometricAttribute(i_attribute))

    def __repr__(self):
        return f'ManufacturingFeature(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-06-11 12:40:47.360445

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.in_interfaces.reference import Reference
from pycatia.mec_mod_interfaces.body import Body
from pycatia.mec_mod_interfaces.shape import Shape


class BooleanShape(Shape):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     MecModInterfaces.Shape
                |                         BooleanShape
                | 
                | Represents the shapes based on boolean operations on other
                | shapes.
                | It is the base object for add, assemble, intersect, remove, and split
                | shapes.
                | 
                | See also:
                |     Add, Assemble, Intersect, Remove, Split, Trim
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.boolean_shape = com_object

    @property
    def body(self) -> Body:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property Body() As Body (Read Only)
                | 
                |     Returns the inserted body.

        :rtype: Body
        """

        return Body(self.boolean_shape.Body)

    def set_operated_object(self, i_reference_object: Reference) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub SetOperatedObject(Reference iReferenceObject)
                | 
                |     Modifies the Second Operand. input object to replace with Body or Volume

        :param Reference i_reference_object:
        :rtype: None
        """
        return self.boolean_shape.SetOperatedObject(i_reference_object.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_operated_object'
        # # vba_code = """
        # # Public Function set_operated_object(boolean_shape)
        # #     Dim iReferenceObject (2)
        # #     boolean_shape.SetOperatedObject iReferenceObject
        # #     set_operated_object = iReferenceObject
        # # End Function
        # # """

        # # system_service = self.application.system_service
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_operating_volume(self, i_reference_object: Reference) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub SetOperatingVolume(Reference iReferenceObject)
                | 
                |     Swaps the operands. Both the Operands must be Volume. This is available
                |     only for Volume Add and Volume UnionTrim Operations

        :param Reference i_reference_object:
        :rtype: None
        """
        return self.boolean_shape.SetOperatingVolume(i_reference_object.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_operating_volume'
        # # vba_code = """
        # # Public Function set_operating_volume(boolean_shape)
        # #     Dim iReferenceObject (2)
        # #     boolean_shape.SetOperatingVolume iReferenceObject
        # #     set_operating_volume = iReferenceObject
        # # End Function
        # # """

        # # system_service = self.application.system_service
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def __repr__(self):
        return f'BooleanShape(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from typing import Iterator

from pycatia.system_interfaces.any_object import AnyObject
from pycatia.system_interfaces.collection import Collection
from pycatia.cat_tps_interfaces.annotation_set import AnnotationSet
from pycatia.types.general import cat_variant


class AssemblyAnnotationSets(Collection):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.Collection
                |                     AssemblyAnnotationSets
                | 
                | Interface for collection of Annotations' Set
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.assembly_annotation_sets = com_object

    def item(self, i_index: cat_variant) -> AnyObject:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func Item(CATVariant iIndex) As AnyObject
                | 
                |     Retrieve a set.

        :param cat_variant i_index:
        :rtype: AnyObject
        """
        return AnyObject(self.assembly_annotation_sets.Item(i_index))

    def load_annotation_sets_list(self) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub LoadAnnotationSetsList()
                | 
                |     Loads the Annotation Sets list. This method is very useful when a cgr
                |     document containing Annotation Set is inserted in the product, because the
                |     Annotation Set is not automatically loaded If the Annotation Set is already
                |     loaded nothing happens.

        :rtype: None
        """
        return self.assembly_annotation_sets.LoadAnnotationSetsList()

    def __getitem__(self, n: int) -> AnnotationSet:
        if (n + 1) > self.count:
            raise StopIteration

        return AnnotationSet(self.assembly_annotation_sets.Item(n + 1))

    def __iter__(self) -> Iterator[AnnotationSet]:
        for i in range(self.count):
            yield self.child_object(self.com_object.Item(i + 1))

    def __repr__(self):
        return f'AssemblyAnnotationSets(name="{self.name}")'
